@@ -134,7 +134,7 @@ class GameBotClient:
         response(stream.body)
         return stream
 
-    def send(self, data):
+    def send(self, data) -> Stream or None:
         if not self.connected:
             return
         sent(f'{data}')
@@ -144,7 +144,7 @@ class GameBotClient:
         self.socket.sendall(stream.encode())
         return self.read()
 
-    def ping(self):
+    def ping(self) -> Stream or None:
         if not self.connected:
             return
         from_addr = f"{self.client_address}"
